

Fix some warnings in the ppc64 build.

Also declare a couple of AIO functions in aio.h rather than aio.c They are
needed for 32-bit emulation support.


 arch/ppc64/boot/main.c        |    3 +--
 arch/ppc64/kernel/prom.c      |    4 ++--
 arch/ppc64/kernel/sys_ppc32.c |    5 +++--
 fs/aio.c                      |    2 --
 include/linux/aio.h           |    3 +++
 5 files changed, 9 insertions(+), 8 deletions(-)

diff -puN arch/ppc64/boot/main.c~ppc64-scruffiness arch/ppc64/boot/main.c
--- 25-power4/arch/ppc64/boot/main.c~ppc64-scruffiness	2003-02-26 15:26:33.000000000 -0800
+++ 25-power4-akpm/arch/ppc64/boot/main.c	2003-02-26 15:27:11.000000000 -0800
@@ -12,12 +12,11 @@
 #include "ppc32-types.h"
 #include "zlib.h"
 #include <linux/elf.h>
+#include <linux/string.h>
 #include <asm/processor.h>
 #include <asm/page.h>
 #include <asm/bootinfo.h>
 
-void memmove(void *dst, void *im, int len);
-
 extern void *finddevice(const char *);
 extern int getprop(void *, const char *, void *, int);
 extern void printk(char *fmt, ...);
diff -puN arch/ppc64/kernel/prom.c~ppc64-scruffiness arch/ppc64/kernel/prom.c
--- 25-power4/arch/ppc64/kernel/prom.c~ppc64-scruffiness	2003-02-26 15:28:20.000000000 -0800
+++ 25-power4-akpm/arch/ppc64/kernel/prom.c	2003-02-26 15:28:45.000000000 -0800
@@ -2040,11 +2040,11 @@ prom_bi_rec_verify(struct bi_record *bi_
 	if ( bi_recs == NULL || bi_recs->tag != BI_FIRST )
 		return NULL;
 
-	last = (struct bi_record *)bi_recs->data[0];
+	last = (struct bi_record *)(long)bi_recs->data[0];
 	if ( last == NULL || last->tag != BI_LAST )
 		return NULL;
 
-	first = (struct bi_record *)last->data[0];
+	first = (struct bi_record *)(long)last->data[0];
 	if ( first == NULL || first != bi_recs )
 		return NULL;
 
diff -puN arch/ppc64/kernel/sys_ppc32.c~ppc64-scruffiness arch/ppc64/kernel/sys_ppc32.c
--- 25-power4/arch/ppc64/kernel/sys_ppc32.c~ppc64-scruffiness	2003-02-26 15:29:19.000000000 -0800
+++ 25-power4-akpm/arch/ppc64/kernel/sys_ppc32.c	2003-02-26 15:37:18.000000000 -0800
@@ -33,6 +33,7 @@
 #include <linux/shm.h>
 #include <linux/slab.h>
 #include <linux/uio.h>
+#include <linux/aio.h>
 #include <linux/nfs_fs.h>
 #include <linux/smb_fs.h>
 #include <linux/smb_mount.h>
@@ -3787,7 +3788,7 @@ long sys32_io_submit(aio_context_t ctx_i
 		struct iocb tmp;
 		u32 *user_iocb;
 
-		if (unlikely(__get_user(user_iocb, iocbpp + i))) {
+		if (unlikely(__get_user((u32)(long)user_iocb, iocbpp + i))) {
 			ret = -EFAULT;
 			break;
 		}
@@ -3797,7 +3798,7 @@ long sys32_io_submit(aio_context_t ctx_i
 			break;
 		}
 
-		ret = io_submit_one(ctx, user_iocb, &tmp);
+		ret = io_submit_one(ctx, (struct iocb *)user_iocb, &tmp);
 		if (ret)
 			break;
 	}
diff -puN include/linux/aio.h~ppc64-scruffiness include/linux/aio.h
--- 25-power4/include/linux/aio.h~ppc64-scruffiness	2003-02-26 15:30:20.000000000 -0800
+++ 25-power4-akpm/include/linux/aio.h	2003-02-26 15:31:43.000000000 -0800
@@ -147,6 +147,9 @@ extern int FASTCALL(aio_complete(struct 
 extern void FASTCALL(__put_ioctx(struct kioctx *ctx));
 struct mm_struct;
 extern void FASTCALL(exit_aio(struct mm_struct *mm));
+extern struct kioctx *lookup_ioctx(unsigned long ctx_id);
+extern int FASTCALL(io_submit_one(struct kioctx *ctx,
+			struct iocb *user_iocb, struct iocb *iocb));
 
 #define get_ioctx(kioctx)	do { if (unlikely(atomic_read(&(kioctx)->users) <= 0)) BUG(); atomic_inc(&(kioctx)->users); } while (0)
 #define put_ioctx(kioctx)	do { if (unlikely(atomic_dec_and_test(&(kioctx)->users))) __put_ioctx(kioctx); else if (unlikely(atomic_read(&(kioctx)->users) < 0)) BUG(); } while (0)
diff -puN fs/aio.c~ppc64-scruffiness fs/aio.c
--- 25-power4/fs/aio.c~ppc64-scruffiness	2003-02-26 15:31:48.000000000 -0800
+++ 25-power4-akpm/fs/aio.c	2003-02-26 15:31:55.000000000 -0800
@@ -984,8 +984,6 @@ asmlinkage long sys_io_destroy(aio_conte
 	return -EINVAL;
 }
 
-int FASTCALL(io_submit_one(struct kioctx *ctx, struct iocb *user_iocb,
-				  struct iocb *iocb));
 int io_submit_one(struct kioctx *ctx, struct iocb *user_iocb,
 			 struct iocb *iocb)
 {

_
